@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.shade.relocation;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,19 +16,19 @@ package org.apache.maven.plugins.shade.relocation;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.shade.relocation;
 
 /** @author Jason van Zyl */
-public interface Relocator
-{
+public interface Relocator {
     String ROLE = Relocator.class.getName();
 
-    boolean canRelocatePath( String clazz );
+    boolean canRelocatePath(String clazz);
 
-    String relocatePath( String clazz );
+    String relocatePath(String clazz);
 
-    boolean canRelocateClass( String clazz );
+    boolean canRelocateClass(String clazz);
 
-    String relocateClass( String clazz );
-    
-    String applyToSourceContent( String sourceContent );
+    String relocateClass(String clazz);
+
+    String applyToSourceContent(String sourceContent);
 }
