@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.shade.resource;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,9 +16,7 @@ package org.apache.maven.plugins.shade.resource;
  * specific language governing permissions and limitations
  * under the License.
  */
-
-import org.apache.maven.plugins.shade.relocation.Relocator;
-import org.codehaus.plexus.util.IOUtil;
+package org.apache.maven.plugins.shade.resource;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -30,54 +26,47 @@ import java.util.List;
 import java.util.jar.JarEntry;
 import java.util.jar.JarOutputStream;
 
+import org.apache.maven.plugins.shade.relocation.Relocator;
+import org.codehaus.plexus.util.IOUtil;
+
 /**
  * A resource processor that allows the addition of an arbitrary file
  * content into the shaded JAR.
  */
-public class IncludeResourceTransformer
-    extends AbstractCompatibilityTransformer
-{
+public class IncludeResourceTransformer extends AbstractCompatibilityTransformer {
     File file;
 
     String resource;
 
     private long time = Long.MIN_VALUE;
 
-    public boolean canTransformResource( String r )
-    {
+    public boolean canTransformResource(String r) {
         return false;
     }
 
-    public void processResource( String resource, InputStream is, List<Relocator> relocators, long time )
-        throws IOException
-    {
-        if ( time > this.time )
-        {
-            this.time = time;        
+    public void processResource(String resource, InputStream is, List<Relocator> relocators, long time)
+            throws IOException {
+        if (time > this.time) {
+            this.time = time;
         }
     }
 
-    public boolean hasTransformedResource()
-    {
+    public boolean hasTransformedResource() {
         return file != null && file.exists();
     }
 
-    public void modifyOutputStream( JarOutputStream jos )
-        throws IOException
-    {
-        JarEntry jarEntry = new JarEntry( resource );
-        jarEntry.setTime( time );
+    public void modifyOutputStream(JarOutputStream jos) throws IOException {
+        JarEntry jarEntry = new JarEntry(resource);
+        jarEntry.setTime(time);
 
-        try ( InputStream in = new FileInputStream( file ) )
-        {
-            jos.putNextEntry( jarEntry );
-            IOUtil.copy( in, jos );
+        try (InputStream in = new FileInputStream(file)) {
+            jos.putNextEntry(jarEntry);
+            IOUtil.copy(in, jos);
         }
     }
-    
+
     @Override
-    public String toString()
-    {
+    public String toString() {
         return "IncludeResourceTransformer {resource: '" + resource + "'}";
     }
 }
